#
# spec file for package lttng-modules
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lttng-modules
Version:        2.13.9
Release:        1.30
Summary:        Licensing information for package lttng-modules
License:        GPL-2.0-only AND LGPL-2.1-only AND MIT
Group:          System/Kernel
URL:            https://lttng.org/
Source:         https://lttng.org/files/lttng-modules/%{name}-%{version}.tar.bz2
Source1:        https://lttng.org/files/lttng-modules/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        %{name}-preamble
Source4:        Module.supported
# PATCH-FIX-UPSTREAM lttng-modules-2.13.9-linux-6.3.patch -- Linux 6.3 compatibility.
Patch0:         lttng-modules-2.13.9-linux-6.3.patch
BuildRequires:  %{kernel_module_package_buildreqs}
ExclusiveArch:  %ix86 x86_64 armv7l aarch64 riscv64 ppc64 ppc64le

%description
This package provides licensing documentation for the lttng kmp packages.

%kernel_module_package -p %{name}-preamble -x ec2 xen xenpae vmi um

%prep
%autosetup -p1

set -- *
mkdir source obj

for i in "$@"; do
   case $i in
      LICENSE|LICENSES|ChangeLog) ;;
      *) mv $i source ;;
   esac
done

%build
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
for flavor in %{flavors_to_build}; do
    rm -rf obj/$flavor
    cp -r source obj/$flavor
    cp %{SOURCE4} obj/$flavor
    %make_build -C %{kernel_source $flavor} %{?linux_make_arch} modules \
      M=$PWD/obj/$flavor CONFIG_LTTNG=m CONFIG_LTTNG_CLOCK_PLUGIN_TEST=m
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko /lib/firmware"
for flavor in %{flavors_to_build}; do
    make -C %{kernel_source $flavor} %{?linux_make_arch} modules_install \
      M=$PWD/obj/$flavor CONFIG_LTTNG=m CONFIG_LTTNG_CLOCK_PLUGIN_TEST=m
done

%files
%license LICENSE LICENSES/
%doc ChangeLog

%changelog
* Fri May 26 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.9:
  * Fix: jbd2: use the correct print format (v5.4.229).
  * Fix: jbd2 upper bound for v5.10.163.
  * Fix: jbd2: use the correct print format (v5.10.163).
  * Fix: btrfs: move accessor helpers into accessors.h (v6.2).
- Add lttng-modules-2.13.9-linux-6.3.patch: back-port commits
  23d91ab1f33370551feceddd93a1ecac7213e692,
  f3559e5b06b24ad0336211950792fa97398c5e9a,
  f39b4a3cbff6d286025bd692aaa24ae6f8efb40b,
  6bc8ed7d08c616991451183eaffeeeb80ca0cd1a
  for Linux 6.3 compatibility.
* Fri Jan 13 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.8:
  * Fix: jbd2: use the correct print format.
  * Fix: in_x32_syscall was introduced in v4.7.0.
  * Explicitly skip tracing x32 system calls.
  * Fix: kallsyms wrapper on ppc64el.
  * Fix: Adjust ranges for RHEL 8.6 kernels.
  * Fix: kvm-x86 requires CONFIG_KALLSYMS_ALL.
  * Fix: mm/slab_common: drop kmem_alloc & avoid dereferencing
    fields when not using (v6.1).
* Sun Oct  2 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.7 (changes since 2.13.4):
  * Fix: incorrect stub prototypes when
    CONFIG_HAVE_SYSCALL_TRACEPOINTS=n.
  * Fix: mm/tracing: add 'accounted' entry into output of
    allocation tracepoints (v6.0).
  * Fix: block: remove bdevname (v6.0).
  * Fix: fs/jbd2: Fix the documentation of the
    jbd2_write_superblock() callers (v6.0).
  * Fix: tie compaction probe build to CONFIG_COMPACTION.
  * Fix: net: skb: introduce kfree_skb_reason() (v5.15.58..v5.16).
  * Fix: workqueue: Fix type of cpu in trace event (v5.19).
  * Fix: fs: Remove flags parameter from aops->write_begin (v5.19).
  * Fix: mm/page_alloc: fix tracepoint mm_page_alloc_zone_locked()
    (v5.19).
  * Fix: bytecode validator: reject specialised load field/context
    ref instructions.
  * Fix: bytecode validator: reject specialised load instructions.
  * Fix: honour "user" attribute for array/sequence of user integers.
  * wrapper: powerpc64: fix kernel crash caused by do_get_kallsyms.
  * Fix: event notification: Remove duplicate event enabled check.
  * Fix: event notification capture: validate buffer length.
  * Fix: handle capture page faults as skip field.
  * Fix: event notification capture error handling.
  * Fix: capture_sequence_element_{un,}signed: handle user-space
    input.
  * Fix: notification capture: handle userspace strings.
  * Implement lttng_msgpack_write_user_str.
  * Fix: bytecode interpreter: LOAD_FIELD: handle user fields.
  * Fix: move "user" attribute from field to type.
  * Introduce lttng_copy_from_user_check_nofault.
  * Fix: adjust range v5.10.137 in block probe.
  * Fix: handle integer capture page faults as skip field.
- Drop lttng-modules-2.13.4-linux-5.19.patch: merged upstream.
* Fri Aug 19 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Add lttng-modules-2.13.4-linux-5.19.patch: back-port commits
  6229bbaa423832f6b7c7a658ad11e1d4242752ff,
  5e2f832d59d51589ab69479c7db43c7581fb9346,
  c6da9604b1666780ea4725b3b3d1bfa1548f9c89
  for Linux 5.19 compatibility.
* Fri Jun  3 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.4:
  * Fix: event notifier: racy use of last subbuffer record.
  * Fix: bytecode interpreter context_get_index() leaves byte
    order uninitialised.
  * Fix: "random" tracepoints removed in stable kernels.
  * Fix: random: remove unused tracepoints (v5.10, v5.15).
  * Fix: sched/tracing: Append prev_state to tp args instead
    (v5.18).
  * Fix: mm: compaction: cleanup the compaction trace events
    (v5.18).
  * Fix: scsi: core: Remove <scsi/scsi_request.h> (v5.18).
  * Fix: kprobes: Use rethook for kretprobe if possible (v5.18).
  * Fix: random: remove unused tracepoints (v5.18).
  * Fix: scsi: block: Remove REQ_OP_WRITE_SAME support (v5.18).
  * Fix: block: remove genhd.h (v5.18).
  * Fix: sched/tracing: Don't re-read p->state when emitting
    sched_switch event (v5.18).
  * Fix: KVM: x86: Unexport kvm_x86_ops (v5.18).
  * Fix: do not warn on unknown counter ioctl.
  * Fix: tracepoint event: allow same provider and event name.
  * Fix: compaction migratepages event name.
* Wed May 18 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.3:
  * Fix: incorrect in/out direction for syscall exit.
  * Fix: net: socket: rename SKB_DROP_REASON_SOCKET_FILTER (v5.17).
  * Fix: net: skb: introduce kfree_skb_reason() (v5.17).
  * Fix: random: rather than entropy_store abstraction, use global
    (v5.17).
  * Fix: btrfs: pass fs_info to trace_btrfs_transaction_commit
    (v5.17).
  * Fix: mm: compaction: fix the migration stats in
    trace_mm_compaction_migratepages() (v5.17).
  * Fix: block: remove the ->rq_disk field in struct request
    (v5.17).
  * Fix: block: remove GENHD_FL_SUPPRESS_PARTITION_INFO (v5.17).
  * Document expected ISO8601 time formats in ABI header.
  * Fix: lttng ABI: lttng_counter_ioctl() tainted scalar.
  * Fix: sample discarded events count before reserve.
  * Cleanup: comment alignment in ring buffer config.h.
* Sat Jan 15 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.1:
  * See https://git.lttng.org/?p=lttng-modules.git;a=shortlog;h=refs/tags/v2.13.1
- Drop lttng-modules-2.13.0-linux-5.15.patch: merged upstream.
* Sat Nov 27 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.13.0:
  * See https://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=v2.13.0
- Add lttng-modules-2.13.0-linux-5.15.patch: Linux 5.15
  compatibility (commit ffcc8734 by Michael Jeanson).
- Add ARMv7 and RISC-V to supported architectures.
* Fri Jan 22 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.12.4
  * fix: adjust version range for trace_find_free_extent()
  * Improve the release script
  * Add release maintainer script
  * fix: statedump: undefined symbols caused by incorrect patch
    backport
  * fix: include order for older kernels
  * fix: tracepoint: Optimize using static_call() (v5.10)
  * fix: KVM: x86/mmu: Return unique RET_PF_* values if the
    fault was fixed (v5.10)
  * fix: kvm: x86/mmu: Add TDP MMU PF handler (v5.10)
  * fix: KVM: x86: Add intr/vectoring info and error code to
    kvm_exit tracepoint (v5.10)
  * fix: ext4: fast commit recovery path (v5.10)
  * fix: btrfs: make ordered extent tracepoint take btrfs_inode
    (v5.10)
  * fix: btrfs: tracepoints: output proper root owner for
    trace_find_free_extent() (v5.10)
  * fix: objtool: Rename frame.h -> objtool.h (v5.10)
  * Fix: ressource leak in id tracker
  * fix: strncpy equals destination size warning
* Tue Nov  3 2020 Tony Jones <tonyj@suse.com>
- Update to version 2.12.3 (jsc#SLE-16189)
  Changelog: https://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=v2.12.3
  Delete patch: lttng-modules-fix-leap-15.1.patch
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.11.2:
  * See /usr/share/doc/packages/lttng-modules/ChangeLog
- Rebase and rename lttng-modules-fix-leap-15.0.patch to
  lttng-modules-fix-leap-15.1.patch.
- Update the spec.
* Thu Oct  3 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.10.11 (changes since 2.10.9):
  * Don't print ring-buffer's records count when it is not used.
  * Do not set quiescent state on channel destroy.
  * ring_buffer_frontend.c: Fix init read timer with uninitialised
    flags.
  * random: Only read from /dev/random after its pool has received
    128 bits (v5.2).
  * mm: move recent_rotated pages calculation to
    shrink_inactive_list() (v5.2).
  * mm/vmscan: Simplify trace_reclaim_flags and trace_shrink_flags
    (v5.2).
  * mm/vmscan: Drop may_writepage and classzone_idx from direct
    reclaim begin template (v5.2).
  * timer/trace: Improve timer tracing (v5.2).
  * bitfields: Streamline use of underscores.
  * Silence compiler "always false comparison" warning.
  * bitfield: Shift undefined/implementation defined behaviours.
  * bitfield.h: Move to kernel style SPDX license identifiers.
  * timestamp_end field should include all events within sub-buffer.
  * Remove start and number from syscall_get_arguments() args
    (v5.1).
  * lttng abi documentation: Clarify getter usage requirements.
  * Don't access packet header for stream_id and
    stream_instance_id getters.
  * atomic_long_add_unless() returns a boolean.
  * Revert "KVM: MMU: show mmu_valid_gen..." (v5.1).
  * pipe: Stop using ->can_merge (v5.1).
  * rcu: Remove wrapper definitions for obsolete RCU (v5.1).
  * mm: Create the new vm_fault_t type (v5.1).
  * extra-version-git.sh redirect stderr to /dev/null.
  * Fix gcc-9.1 stack frame size warning.
  * Do not use diagnostic pragma when GCC version is lower than
    4.6.0.
  * Fix a missing define when not building with gcc.
  * lttng-tracepoint module notifier should return NOTIFY_OK.
* Sun Apr 21 2019 Markus Beth <markus.beth@web.de>
- Update to version 2.10.9:
  * Blacklist: kprobe for arm
  * Cleanup: tp mempool: Remove logically dead code.
  * Fix: btrfs: Remove fsid/metadata_fsid fields from btrfs_info.
  * Fix: SUNRPC: Simplify defining common RPC trace events (v5.0).
  * Fix: Replace pointer values with task->tk_pid and
    rpc_clnt->cl_clid.
  * Fix: Remove 'type' argument from access_ok() function (v5.0).
  * Fix: Timer instrumentation for RHEL 7.6.
  * Fix: ext4: Adjust reserved cluster count when removing extents
    (v4.20).
  * Fix: signal: Remove SEND_SIG_FORCED (v4.20).
  * Fix: signal: Distinguish between kernel_siginfo and siginfo
    (v4.20).
- Remove
  lttng-modules-2.10.8-update-instrumentation-for-linux-4.20.patch:
  fixed upstream.
- Rebase lttng-modules-fix-leap-15.0.patch.
* Thu Jan 24 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Add
  lttng-modules-2.10.8-update-instrumentation-for-linux-4.20.patch:
  Update instrumentation on Linux 4.20 (commits 6c484ba2, cef5d79e,
  307021a1).
* Wed Nov 14 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.10.8:
  * Fix: Update kvm instrumentation for SLES12 SP2
    LTSS >= 4.4.121-92.92.
  * Fix: Add missing const to lttng_tracepoint_ptr_deref prototype.
  * Fix: Adapt to kernel relative references.
  * Fix: Implicit declarations caused by buffer size checks.
  * Prevent allocation of buffers if exceeding available memory.
  * Fix: Convert rcu tracepointis to gp_seq (v4.19).
  * Fix: net: Expose sk wmem in sock_exceed_buf_limit tracepoint
    (4.19).
  * Fix: Access migrate_disable field directly.
  * Fix: Out of memory error handling.
- Enable building for the RT flavor on SLE 15+.
- Remove btrfs-constify-tracepoint-arguments.patch: fixed upstream
  for SLE 12.
- Add lttng-modules-fix-leap-15.0.patch: Fix building on Leap 15.0.
* Thu Aug 23 2018 sor.alexei@meowr.ru
- Update to version 2.10.7:
  * Fix: adjust SLE version ranges to build with SP2 and SP3.
  * Fix: Allow alphanumeric characters in the SLE version.
  * Fix: Adjust range for SUSE 4.4.103-92 kernels.
  * Add extra version information framework.
  * Fix: btrfs: Remove the unnecessary fs_info parameter.
  * Fix: asoc: Remove snd_soc_cache_sync() implementation.
  * Fix: asoc: Fix printing jack name.
  * Fix: asoc: Consolidate path trace events.
  * Fix: ASoC level IO tracing removed upstream.
  * Fix: dyntick field added to trace_rcu_dyntick in v4.16.
  * Fix: BUILD_BUG_ON with compile time constant on < v2.6.38.
  * Fix: pid tracker should track "pgid" for noargs probes.
* Sun Jun 17 2018 sor.alexei@meowr.ru
- Update to version 2.10.6:
  * Fix: Update RCU instrumentation for 4.17.
  * Fix: sunrpc instrumentation for 4.17.
  * Fix: Use struct reclaim_stat in mm_vmscan_lru_shrink_inactive
    for 4.17.
  * Fix: Add gfp_flags arg to mm_vmscan_kswapd_wake for 4.17.
  * Update: KVM instrumentation for ubuntu 4.13.0-38.
  * Fix: Update KVM instrumentation for Ubuntu 3.13.0-144.
  * Fix: btrfs instrumentation namespacing.
  * Cleanup: Comment about CONFIG_HOTPLUG_CPU ifdef.
  * Fix: Do not use CONFIG_HOTPLUG_CPU for the new hotplug API.
  * Fix: Update kvm instrumentation for 4.1.50+.
  * Use the memory pool instead of kmalloc.
  * Create a memory pool for temporary tracepoint probes storage.
  * Fix: Use proper pid_ns in the process statedump.
  * Fix: Add variable quoting to shell scripts.
  * Update: KVM instrumentation for fedora 4.14.13-300.
  * Fix: Add Fedora version macros.
  * Fix: Update btrfs instrumentation for SuSE 4.4.114-92.
  * Fix: Update block instrumentation for SuSE 4.4.114-92.
  * Fix: Update rcu instrumentation for v4.16.
  * Fix: Update vmscan instrumentation for v4.16.
  * Fix: Update timer instrumentation on 4.16 and 4.14-rt.
  * Update kvm instrumentation for debian kernel 4.14.0-3.
- Remove
  lttng-modules-2.10.5-update-instrumentation-for-linux-4.16.patch.
* Sun Apr  8 2018 sor.alexei@meowr.ru
- Rebase btrfs-constify-tracepoint-arguments.patch.
- Add
  lttng-modules-2.10.5-update-instrumentation-for-linux-4.16.patch:
  Update instrumentation on Linux 4.16 (commits 562860a, 9cf057f).
* Sun Feb  4 2018 sor.alexei@meowr.ru
- Update to version 2.10.5:
  * Fix network instrumentation protocol enum.
  * Update btrfs instrumentation for SUSE's kernel 4.4.103-6.
  * Update block instrumentation for SUSE's kernel 4.4.73-5.
  * Fix global_dirty_limit for kernel v4.2 and up.
  * Fix network instrumentation handling of corrupted TCP headers.
  * Add missing uaccess.h include from kstrtox.h wrapper.
  * Update kvm instrumentation for 4.14.14+, 4.9.77+, 4.4.112+.
  * Fix: btrfs_delayed_ref_head was unwired since v3.12.
  * Fix Debian kernel version parsing.
  * Fix block instrumentation 4.14+ NULL pointer dereference.
  * Update sock instrumentation for 4.15.
  * Fix: ACCESS_ONCE() was removed in kernel 4.15.
  * Fix sched instrumentation on stable RT kernels.
  * timer API transition for kernel 4.15.
  * Don't nest get online cpus.
  * Fix lttng_channel_syscall_mask() bool use in bitfield.
  * Update kmem instrumentation for kernel 4.15.
- Remove lttng-modules-2.10.4-fix-kvm.patch.
* Wed Jan 24 2018 sor.alexei@meowr.ru
- Add lttng-modules-2.10.4-fix-kvm.patch: Update KVM
  instrumentation for Linux 4.15 (commits 3363052, d9f561b,
  5ccd696, bda29b7).
* Fri Dec 29 2017 sor.alexei@meowr.ru
- Update to version 2.10.4:
  * Fix: lttng_kvmalloc helper NULL pointer OOP.
- Use tarball signing.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 2.10.3 (changes since 2.10.0):
  * Fix a version check error in btrfs instrumentation.
  * Update the btrfs instrumentation for kernel 4.14.
  * Update writeback instrumentation for kernel 4.14.
  * Update block instrumentation for kernel 4.14.
  * Fix a vmalloc wrapper on kernel < 2.6.38.
  * Fix a vmalloc wrapper on kernel >= 4.12.
  * Add a kmalloc failover to vmalloc.
  * Fix mmap: caches aliased on virtual addresses.
  * Update ext4 instrumentation for kernel 4.13.
  * Fix lttng-logger get_user_pages_fast error handling.
- Rebase btrfs-constify-tracepoint-arguments.patch.
- Only apply btrfs-constify-tracepoint-arguments.patch on SLE.
- Also build for x86-32, aarch64, ppc64, ppc64le.
- Spec cleanup.
* Thu Aug 31 2017 tonyj@suse.com
- Update to version 3.10 for SLE15 (bsc#1055683)
  Temp disable RT builds
  Drop patch: cve-2016-0728-check-reference-counts-for-overflow.patch
  Drop patch: fix-btrfs-instrumentation-for-4.8-kernel.patch
  Drop patch: tracepoint-event-add-tp_code_post.patch
  Drop patch: update-block-instrumentation-to-compile-on-4.8-kernels.patch
  Modify patch: btrfs-constify-tracepoint-arguments.patch
* Tue Jun 20 2017 tonyj@suse.com
- Constify btrfs tracepoints to resolve build failures (bsc#1044912)
  New patch: btrfs-constify-tracepoint-arguments.patch
* Mon May  8 2017 lnussel@suse.de
- Don't build for rt flavor on openSUSE. Doesn't exist there. (bsc#1013845)
* Thu Apr 27 2017 tonyj@suse.com
- Update lttng for btrfs_sync_fs change (bsc#1036276)
  New patch: fix-btrfs-instrumentation-for-4.8-kernel.patch
* Tue Mar 14 2017 tonyj@suse.com
- Make previous change (bsc#1020989,fate#322379) apply to RT kernels
* Wed Mar  8 2017 tonyj@suse.com
- Resolve build errors in staging due to kernel block layer API FATE.
  (bsc#1020989,fate#322379) currently applying only to !RT kernels.
  new patch: tracepoint-event-add-tp_code_post.patch
  new patch: update-block-instrumentation-to-compile-on-4.8-kernels.patch
* Wed Oct 19 2016 lpechacek@suse.com
- Enabled RT KMP build (bsc#1005578)
* Fri Jan 22 2016 lpechacek@suse.com
- Disable RT KMP build (bsc#962719)
* Thu Jan 21 2016 tonyj@suse.com
- Upgrade to 2.7.1 bugfix release to correct v4.4 build failures (bsc#962719)
- Add preventative fix for cve-2016-0728
  new patch: cve-2016-0728-check-reference-counts-for-overflow.patch
* Thu Oct  8 2015 jcheung@suse.com
- Enable RT KMP build (bsc#948840)
* Mon Oct  5 2015 tonyj@suse.com
- Upgrade to release version 2.7.0 (FATE#319273)
  See http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=v2.7.0
  for changelog from v2.7.0-rc1 to v2.7.0
* Tue Jul 28 2015 tonyj@suse.com
- Update to version 2.7.0-rc1 (FATE#319273)
  Drop patch: fix-mm_compaction_migratepages-tp.diff
  Drop patch: fix-update-block-instrumentation-to-3.15-kernel.patch
  Changelog for differences between 2.4.0 and this point may be found at:
    http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=c103647d3a1a5090737a4339c584ac294b4ab676
* Mon Feb  9 2015 meissner@suse.com
- rebuild to follow the kabi change in bsc#916842
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Jun  4 2014 tonyj@suse.com
- Fix build errors resulting from block_rq_complete trace event changes
  (3.12.21 stable kernel update)
- Previous fix (update mm_compaction_migratepages) generated build warnings
  as code-change introduced was dead,  correct via static function called
  from input parameter.
- Build against full kernel sources thus enabling kvm, btrfs and ext4 probes.
* Tue May 20 2014 tonyj@suse.com
- Update mm_compaction_migratepages trace-event to reflect kernel commit
  ddc38a292 (mm/compaction: do not count migratepages when unnecessary)
* Tue Apr 15 2014 tonyj@suse.com
- Update to version 2.4.1
  Changelog:
  * Fix: rcu instrumentation: add const qualifier to char pointers
  * Fix: add missing module version information
  * Fix: block instrumentation: < 3.14 don't have bi_iter
  * Fix: update btrfs instrumentation to kernel 3.14
  * Fix: update block layer instrumentation to kernel 3.14
  * Fix file permissions for lttng-statedump-impl.c
- Correct supported module paths (bnc#872683)
* Wed Apr  9 2014 tonyj@suse.com
- Mark modules as supported (bnc#872683,  regression of previous
  bnc#774206).
* Fri Feb 28 2014 tonyj@suse.com
- Update to version 2.4.0. Changelog for changes between 2.3.0 and 2.4.0
  may be found at: http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=refs/heads/stable-2.4
* Mon Feb 10 2014 tonyj@suse.com
- Update to version 2.3.4.
- Package license files in main lttng-modules package
* Tue Mar 19 2013 lpechacek@suse.com
- excluded -rt variant from non-x86_64 architectures, build
  exclusively on x86_64
* Thu Mar 14 2013 lpechacek@suse.com
- Set $BRP_PESIGN_FILES in the %%install section so that modules
  are signed in the buildservice (fate#314552).
* Mon Mar 11 2013 tonyj@suse.com
- Upgrade to version 2.1.1 (FATE#314846)
  Changelog 2.1.1:
  * Fix: statedump: missing locking, use lttng_iterate_fd
  * Implement lttng_iterate_fd wrapper
  * Fix check in lttng_strlen_user_inatomic
  * Fix: statedump hang/too early completion due to logic error
  * Fix: statedump hang due to incorrect wait/wakeup use
  Changelog 2.1.0:
  * put_ulong calls in lib_ring_buffer_compat_ioctl() should be compat
  * wrapper/perf.h: Fix kernel version condition
  * Fix possible kernel build errors with linux-patches
  * Add missing MIT license text to 3 files under this license
  * Check if interrupt action name is not null in statedump
  * Fix exec instrumentation: only for kernels 3.4.0 and higher
  * Add TRACE_EVENT(sched_process_exec) to sched.h
  * lib/ringbuffer/frontend_api.h: Include linux/prefetch.h.
  * Fix warning with 3.6.0 kernel
  * ABI with support for compat 32/64 bits
  * Perform calculation on bit size in 64-bit
  * Use uint64_t for packet header content size and packet size
  * Fix: compat layer only on supported architectures
  * Fix ring buffer 32/64 bits compat
  * Fix cleanup: move lttng-tracer-core.h include to lib ringbuffer config.h
  * Fix ring_buffer_frontend.c: missing include lttng-tracer-core.h
  * Fix: statedump missing check for NULL namespace
  Changelog 2.1.0-rc1:
  * fix timestamps on architectures without CONFIG_KTIME_SCALAR
  * Support for linux kernels 2.6.32 through 2.6.37
  * Document limitation of vppid and ppid context wrt eventual RCU instrumentation
  * Cleanup: no need to hold RCU read-side lock when reading current nsproxy
  * Add env hostname information
  * Fix: lttng_statedump_process_state for each PID NS has infinite loop
  * lttng_statedump_process_state for each PID NS
  * Support the hostname context
  * Fix: statedump namespaced pid, tid and ppid
  * Fix: statedump: disable vm maps enumeration
  * Fix: ensure userspace accesses are done with _inatomic
  * Fix: vppid context should test for current nsproxy
  * Add MIPS system call support
  * Change mode of lttng-syscalls-generate-headers.sh to 755
  * cleanup: fix typo in syscall instrumentation header
  * Cleanup: remove trailing whitespace in README
  * trace event: introduce TP_MODULE_NOAUTOLOAD and TP_MODULE_NOINIT
  * LTTng: probe-statedump: add #include <linux/sched.h>
  * fix: signal_generate event should print utf8 for comm field
  * Makes write operation a parameter for tp_memcpy macro
  * Add coding style document
  * Update instrumentation/events README file
  * Add makefile target for preprocessor
  * Fix: free_event_id check should compare unsigned int with -1U
  * Use unsigned long type for events discarded counter
  * Fix: update signal instrumentation for 3.4 kernel
  * LTTng Modules ARM syscall instrumentation
  * Fix: generate header missing echo -e for escape chars
  * Fix: add missing uaccess.h include (for ARM)
  * README: Document that CONFIG_MODULES is required
  * Fix: README typo
  * Fix: document required and optional kernel config options in README
* Fri Feb 22 2013 tonyj@suse.com
- Fix build error (lttng-modules-perf-wrapper-suse.patch)
* Fri Jun 29 2012 tonyj@suse.com
- Update to release 2.0.4
* Mon Jun  4 2012 tonyj@suse.com
- Update to release 2.0.3
* Fri Apr 20 2012 tonyj@suse.com
- Update to release 2.0.2
* Thu Apr 12 2012 tonyj@suse.com
- Update to release 2.0.1
* Wed Mar 21 2012 tonyj@suse.com
- Update to release 2.0.0
* Wed Mar 14 2012 tonyj@suse.com
- Update to version 2.0.0-rc2
* Mon Feb 27 2012 tonyj@suse.com
- Update to version 2.0.0-rc1
* Wed Jan  4 2012 tonyj@suse.com
- Update to version 2.0-pre11
